import { IDeviceConfig } from "../config";
import { ReferenceToken, PTZConfiguration, AuxiliaryData, PTZSpeed, PTZVector, GeoLocation, PresetTour, PTZPresetTourOperation } from "./types";
export declare class ONVIFPTZ {
    private config;
    constructor(config: IDeviceConfig);
    /**
     * Returns the capabilities of the PTZ service. The result is returned in a typed answer.
     */
    static GetServiceCapabilities(): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *   Get the descriptions of the available PTZ Nodes.
     *
     *   A PTZ-capable device may have multiple PTZ Nodes. The PTZ Nodes may represent
     *   mechanical PTZ drivers, uploaded PTZ drivers or digital PTZ drivers. PTZ Nodes are the
     *   lowest level entities in the PTZ control API and reflect the supported PTZ capabilities. The
     *   PTZ Node is referenced either by its name or by its reference token.
     *
     */
    static GetNodes(): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Get a specific PTZ Node identified by a reference
     *           token or a name.
     *
     */
    static GetNode(NodeToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Get a specific PTZconfiguration from the device, identified by its reference token or name.
     *
     *   The default Position/Translation/Velocity Spaces are introduced to allow NVCs sending move
     *   requests without the need to specify a certain coordinate system. The default Speeds are
     *   introduced to control the speed of move requests (absolute, relative, preset), where no
     *   explicit speed has been set.
     *   The allowed pan and tilt range for Pan/Tilt Limits is defined by a two-dimensional space range
     *   that is mapped to a specific Absolute Pan/Tilt Position Space. At least one Pan/Tilt Position
     *   Space is required by the PTZNode to support Pan/Tilt limits. The limits apply to all supported
     *   absolute, relative and continuous Pan/Tilt movements. The limits shall be checked within the
     *   coordinate system for which the limits have been specified. That means that even if
     *   movements are specified in a different coordinate system, the requested movements shall be
     *   transformed to the coordinate system of the limits where the limits can be checked. When a
     *   relative or continuous movements is specified, which would leave the specified limits, the PTZ
     *   unit has to move along the specified limits. The Zoom Limits have to be interpreted
     *   accordingly.
     *
     */
    static GetConfiguration(PTZConfigurationToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *           Get all the existing PTZConfigurations from the device.
     *
     *   The default Position/Translation/Velocity Spaces are introduced to allow NVCs sending move
     *   requests without the need to specify a certain coordinate system. The default Speeds are
     *   introduced to control the speed of move requests (absolute, relative, preset), where no
     *   explicit speed has been set.
     *   The allowed pan and tilt range for Pan/Tilt Limits is defined by a two-dimensional space range
     *   that is mapped to a specific Absolute Pan/Tilt Position Space. At least one Pan/Tilt Position
     *   Space is required by the PTZNode to support Pan/Tilt limits. The limits apply to all supported
     *   absolute, relative and continuous Pan/Tilt movements. The limits shall be checked within the
     *   coordinate system for which the limits have been specified. That means that even if
     *   movements are specified in a different coordinate system, the requested movements shall be
     *   transformed to the coordinate system of the limits where the limits can be checked. When a
     *   relative or continuous movements is specified, which would leave the specified limits, the PTZ
     *   unit has to move along the specified limits. The Zoom Limits have to be interpreted
     *   accordingly.
     *
     */
    static GetConfigurations(): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *           Set/update a existing PTZConfiguration on the device.
     *
     */
    static SetConfiguration(PTZConfiguration: PTZConfiguration, ForcePersistence: boolean): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *   List supported coordinate systems including their range limitations. Therefore, the options
     *   MAY differ depending on whether the PTZ Configuration is assigned to a Profile containing a
     *   Video Source Configuration. In that case, the options may additionally contain coordinate
     *   systems referring to the image coordinate system described by the Video Source
     *   Configuration. If the PTZ Node supports continuous movements, it shall return a Timeout Range within
     *   which Timeouts are accepted by the PTZ Node.
     *
     */
    static GetConfigurationOptions(ConfigurationToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *           Operation to send auxiliary commands to the PTZ device
     *           mapped by the PTZNode in the selected profile. The
     *           operation is supported
     *           if the AuxiliarySupported element of the PTZNode is true
     *
     */
    static SendAuxiliaryCommand(ProfileToken: ReferenceToken, AuxiliaryData: AuxiliaryData): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *           Operation to request all PTZ presets for the PTZNode
     *           in the selected profile. The operation is supported if there is support
     *           for at least on PTZ preset by the PTZNode.
     */
    static GetPresets(ProfileToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *   The SetPreset command saves the current device position parameters so that the device can
     *   move to the saved preset position through the GotoPreset operation.
     *   In order to create a new preset, the SetPresetRequest contains no PresetToken. If creation is
     *   successful, the Response contains the PresetToken which uniquely identifies the Preset. An
     *   existing Preset can be overwritten by specifying the PresetToken of the corresponding Preset.
     *   In both cases (overwriting or creation) an optional PresetName can be specified. The
     *   operation fails if the PTZ device is moving during the SetPreset operation.
     *   The device MAY internally save additional states such as imaging properties in the PTZ
     *   Preset which then should be recalled in the GotoPreset operation.
     */
    static SetPreset(ProfileToken: ReferenceToken, PresetName?: string, PresetToken?: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *           Operation to remove a PTZ preset for the Node in
     *           the
     *           selected profile. The operation is supported if the
     *           PresetPosition
     *           capability exists for teh Node in the
     *           selected profile.
     *
     */
    static RemovePreset(ProfileToken: ReferenceToken, PresetToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *           Operation to go to a saved preset position for the
     *           PTZNode in the selected profile. The operation is supported if there is
     *           support for at least on PTZ preset by the PTZNode.
     */
    static GotoPreset(ProfileToken: ReferenceToken, PresetToken: ReferenceToken, Speed?: PTZSpeed): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *           Operation to move the PTZ device to it's "home" position. The operation is supported if the HomeSupported element in the PTZNode is true.
     */
    static GotoHomePosition(ProfileToken: ReferenceToken, Speed?: PTZSpeed): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to save current position as the home position.
     *   The SetHomePosition command returns with a failure if the “home” position is fixed and
     *   cannot be overwritten. If the SetHomePosition is successful, it is possible to recall the
     *   Home Position with the GotoHomePosition command.
     */
    static SetHomePosition(ProfileToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation for continuous Pan/Tilt and Zoom movements. The operation is supported if the PTZNode supports at least one continuous Pan/Tilt or Zoom space. If the space argument is omitted, the default space set by the PTZConfiguration will be used.
     */
    static ContinuousMove(ProfileToken: ReferenceToken, Velocity: PTZSpeed, Timeout?: string): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation for Relative Pan/Tilt and Zoom Move. The operation is supported if the PTZNode supports at least one relative Pan/Tilt or Zoom space.
     *   The speed argument is optional. If an x/y speed value is given it is up to the device to either use
     *   the x value as absolute resoluting speed vector or to map x and y to the component speed.
     *   If the speed argument is omitted, the default speed set by the PTZConfiguration will be used.
     *
     */
    static RelativeMove(ProfileToken: ReferenceToken, Translation: PTZVector, Speed?: PTZSpeed): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     *
     *   Operation to request PTZ status for the Node in the
     *   selected profile.
     */
    static GetStatus(ProfileToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to move pan,tilt or zoom to a absolute destination.
     *   The speed argument is optional. If an x/y speed value is given it is up to the device to either use
     *   the x value as absolute resoluting speed vector or to map x and y to the component speed.
     *   If the speed argument is omitted, the default speed set by the PTZConfiguration will be used.
     *
     */
    static AbsoluteMove(ProfileToken: ReferenceToken, Position: PTZVector, Speed?: PTZSpeed): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to move pan,tilt or zoom to point to a destination based on the geolocation of the target.
     *   The speed argument is optional. If an x/y speed value is given it is up to the device to either use
     *   the x value as absolute resoluting speed vector or to map x and y to the component speed.
     *   If the speed argument is omitted, the default speed set by the PTZConfiguration will be used.
     *   The area height and area dwidth parameters are optional, they can be used independently and may be used
     *   by the device to automatically determine the best zoom level to show the target.
     *
     */
    static GeoMove(ProfileToken: ReferenceToken, Target: GeoLocation, Speed?: PTZSpeed, AreaHeight?: number, AreaWidth?: number): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to stop ongoing pan, tilt and zoom movements of absolute relative and continuous type.
     *   If no stop argument for pan, tilt or zoom is set, the device will stop all ongoing pan, tilt and zoom movements.
     */
    static Stop(ProfileToken: ReferenceToken, PanTilt?: boolean, Zoom?: boolean): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to request PTZ preset tours in the selected media profiles.
     */
    static GetPresetTours(ProfileToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to request a specific PTZ preset tour in the selected media profile.
     */
    static GetPresetTour(ProfileToken: ReferenceToken, PresetTourToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to request available options to configure PTZ preset tour.
     */
    static GetPresetTourOptions(ProfileToken: ReferenceToken, PresetTourToken?: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to create a preset tour for the selected media profile.
     */
    static CreatePresetTour(ProfileToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to modify a preset tour for the selected media profile.
     */
    static ModifyPresetTour(ProfileToken: ReferenceToken, PresetTour: PresetTour): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to perform specific operation on the preset tour in selected media profile.
     */
    static OperatePresetTour(ProfileToken: ReferenceToken, PresetTourToken: ReferenceToken, Operation: PTZPresetTourOperation): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to delete a specific preset tour from the media profile.
     */
    static RemovePresetTour(ProfileToken: ReferenceToken, PresetTourToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Operation to get all available PTZConfigurations that can be added to the referenced media profile.
     *   A device providing more than one PTZConfiguration or more than one VideoSourceConfiguration or which has any other resource
     *   interdependency between PTZConfiguration entities and other resources listable in a media profile should implement this operation.
     *   PTZConfiguration entities returned by this operation shall not fail on adding them to the referenced media profile.
     *
     */
    static GetCompatibleConfigurations(ProfileToken: ReferenceToken): import("typescript-monads").IReader<IDeviceConfig, import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>>;
    /**
     * Returns the capabilities of the PTZ service. The result is returned in a typed answer.
     */
    GetServiceCapabilities(): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *   Get the descriptions of the available PTZ Nodes.
     *
     *   A PTZ-capable device may have multiple PTZ Nodes. The PTZ Nodes may represent
     *   mechanical PTZ drivers, uploaded PTZ drivers or digital PTZ drivers. PTZ Nodes are the
     *   lowest level entities in the PTZ control API and reflect the supported PTZ capabilities. The
     *   PTZ Node is referenced either by its name or by its reference token.
     *
     */
    GetNodes(): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Get a specific PTZ Node identified by a reference
     *           token or a name.
     *
     */
    GetNode(NodeToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Get a specific PTZconfiguration from the device, identified by its reference token or name.
     *
     *   The default Position/Translation/Velocity Spaces are introduced to allow NVCs sending move
     *   requests without the need to specify a certain coordinate system. The default Speeds are
     *   introduced to control the speed of move requests (absolute, relative, preset), where no
     *   explicit speed has been set.
     *   The allowed pan and tilt range for Pan/Tilt Limits is defined by a two-dimensional space range
     *   that is mapped to a specific Absolute Pan/Tilt Position Space. At least one Pan/Tilt Position
     *   Space is required by the PTZNode to support Pan/Tilt limits. The limits apply to all supported
     *   absolute, relative and continuous Pan/Tilt movements. The limits shall be checked within the
     *   coordinate system for which the limits have been specified. That means that even if
     *   movements are specified in a different coordinate system, the requested movements shall be
     *   transformed to the coordinate system of the limits where the limits can be checked. When a
     *   relative or continuous movements is specified, which would leave the specified limits, the PTZ
     *   unit has to move along the specified limits. The Zoom Limits have to be interpreted
     *   accordingly.
     *
     */
    GetConfiguration(PTZConfigurationToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *           Get all the existing PTZConfigurations from the device.
     *
     *   The default Position/Translation/Velocity Spaces are introduced to allow NVCs sending move
     *   requests without the need to specify a certain coordinate system. The default Speeds are
     *   introduced to control the speed of move requests (absolute, relative, preset), where no
     *   explicit speed has been set.
     *   The allowed pan and tilt range for Pan/Tilt Limits is defined by a two-dimensional space range
     *   that is mapped to a specific Absolute Pan/Tilt Position Space. At least one Pan/Tilt Position
     *   Space is required by the PTZNode to support Pan/Tilt limits. The limits apply to all supported
     *   absolute, relative and continuous Pan/Tilt movements. The limits shall be checked within the
     *   coordinate system for which the limits have been specified. That means that even if
     *   movements are specified in a different coordinate system, the requested movements shall be
     *   transformed to the coordinate system of the limits where the limits can be checked. When a
     *   relative or continuous movements is specified, which would leave the specified limits, the PTZ
     *   unit has to move along the specified limits. The Zoom Limits have to be interpreted
     *   accordingly.
     *
     */
    GetConfigurations(): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *           Set/update a existing PTZConfiguration on the device.
     *
     */
    SetConfiguration(PTZConfiguration: PTZConfiguration, ForcePersistence: boolean): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *   List supported coordinate systems including their range limitations. Therefore, the options
     *   MAY differ depending on whether the PTZ Configuration is assigned to a Profile containing a
     *   Video Source Configuration. In that case, the options may additionally contain coordinate
     *   systems referring to the image coordinate system described by the Video Source
     *   Configuration. If the PTZ Node supports continuous movements, it shall return a Timeout Range within
     *   which Timeouts are accepted by the PTZ Node.
     *
     */
    GetConfigurationOptions(ConfigurationToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *           Operation to send auxiliary commands to the PTZ device
     *           mapped by the PTZNode in the selected profile. The
     *           operation is supported
     *           if the AuxiliarySupported element of the PTZNode is true
     *
     */
    SendAuxiliaryCommand(ProfileToken: ReferenceToken, AuxiliaryData: AuxiliaryData): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *           Operation to request all PTZ presets for the PTZNode
     *           in the selected profile. The operation is supported if there is support
     *           for at least on PTZ preset by the PTZNode.
     */
    GetPresets(ProfileToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *   The SetPreset command saves the current device position parameters so that the device can
     *   move to the saved preset position through the GotoPreset operation.
     *   In order to create a new preset, the SetPresetRequest contains no PresetToken. If creation is
     *   successful, the Response contains the PresetToken which uniquely identifies the Preset. An
     *   existing Preset can be overwritten by specifying the PresetToken of the corresponding Preset.
     *   In both cases (overwriting or creation) an optional PresetName can be specified. The
     *   operation fails if the PTZ device is moving during the SetPreset operation.
     *   The device MAY internally save additional states such as imaging properties in the PTZ
     *   Preset which then should be recalled in the GotoPreset operation.
     */
    SetPreset(ProfileToken: ReferenceToken, PresetName: string, PresetToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *           Operation to remove a PTZ preset for the Node in
     *           the
     *           selected profile. The operation is supported if the
     *           PresetPosition
     *           capability exists for teh Node in the
     *           selected profile.
     *
     */
    RemovePreset(ProfileToken: ReferenceToken, PresetToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *           Operation to go to a saved preset position for the
     *           PTZNode in the selected profile. The operation is supported if there is
     *           support for at least on PTZ preset by the PTZNode.
     */
    GotoPreset(ProfileToken: ReferenceToken, PresetToken: ReferenceToken, Speed: PTZSpeed): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *           Operation to move the PTZ device to it's "home" position. The operation is supported if the HomeSupported element in the PTZNode is true.
     */
    GotoHomePosition(ProfileToken: ReferenceToken, Speed: PTZSpeed): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to save current position as the home position.
     *   The SetHomePosition command returns with a failure if the “home” position is fixed and
     *   cannot be overwritten. If the SetHomePosition is successful, it is possible to recall the
     *   Home Position with the GotoHomePosition command.
     */
    SetHomePosition(ProfileToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation for continuous Pan/Tilt and Zoom movements. The operation is supported if the PTZNode supports at least one continuous Pan/Tilt or Zoom space. If the space argument is omitted, the default space set by the PTZConfiguration will be used.
     */
    ContinuousMove(ProfileToken: ReferenceToken, Velocity: PTZSpeed, Timeout: string): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation for Relative Pan/Tilt and Zoom Move. The operation is supported if the PTZNode supports at least one relative Pan/Tilt or Zoom space.
     *   The speed argument is optional. If an x/y speed value is given it is up to the device to either use
     *   the x value as absolute resoluting speed vector or to map x and y to the component speed.
     *   If the speed argument is omitted, the default speed set by the PTZConfiguration will be used.
     *
     */
    RelativeMove(ProfileToken: ReferenceToken, Translation: PTZVector, Speed: PTZSpeed): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     *
     *   Operation to request PTZ status for the Node in the
     *   selected profile.
     */
    GetStatus(ProfileToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to move pan,tilt or zoom to a absolute destination.
     *   The speed argument is optional. If an x/y speed value is given it is up to the device to either use
     *   the x value as absolute resoluting speed vector or to map x and y to the component speed.
     *   If the speed argument is omitted, the default speed set by the PTZConfiguration will be used.
     *
     */
    AbsoluteMove(ProfileToken: ReferenceToken, Position: PTZVector, Speed: PTZSpeed): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to move pan,tilt or zoom to point to a destination based on the geolocation of the target.
     *   The speed argument is optional. If an x/y speed value is given it is up to the device to either use
     *   the x value as absolute resoluting speed vector or to map x and y to the component speed.
     *   If the speed argument is omitted, the default speed set by the PTZConfiguration will be used.
     *   The area height and area dwidth parameters are optional, they can be used independently and may be used
     *   by the device to automatically determine the best zoom level to show the target.
     *
     */
    GeoMove(ProfileToken: ReferenceToken, Target: GeoLocation, Speed: PTZSpeed, AreaHeight: number, AreaWidth: number): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to stop ongoing pan, tilt and zoom movements of absolute relative and continuous type.
     *   If no stop argument for pan, tilt or zoom is set, the device will stop all ongoing pan, tilt and zoom movements.
     */
    Stop(ProfileToken: ReferenceToken, PanTilt: boolean, Zoom: boolean): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to request PTZ preset tours in the selected media profiles.
     */
    GetPresetTours(ProfileToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to request a specific PTZ preset tour in the selected media profile.
     */
    GetPresetTour(ProfileToken: ReferenceToken, PresetTourToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to request available options to configure PTZ preset tour.
     */
    GetPresetTourOptions(ProfileToken: ReferenceToken, PresetTourToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to create a preset tour for the selected media profile.
     */
    CreatePresetTour(ProfileToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to modify a preset tour for the selected media profile.
     */
    ModifyPresetTour(ProfileToken: ReferenceToken, PresetTour: PresetTour): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to perform specific operation on the preset tour in selected media profile.
     */
    OperatePresetTour(ProfileToken: ReferenceToken, PresetTourToken: ReferenceToken, Operation: PTZPresetTourOperation): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to delete a specific preset tour from the media profile.
     */
    RemovePresetTour(ProfileToken: ReferenceToken, PresetTourToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
    /**
     * Operation to get all available PTZConfigurations that can be added to the referenced media profile.
     *   A device providing more than one PTZConfiguration or more than one VideoSourceConfiguration or which has any other resource
     *   interdependency between PTZConfiguration entities and other resources listable in a media profile should implement this operation.
     *   PTZConfiguration entities returned by this operation shall not fail on adding them to the referenced media profile.
     *
     */
    GetCompatibleConfigurations(ProfileToken: ReferenceToken): import("rxjs").Observable<import("typescript-monads").IResult<import("../soap/request").IResultStructure<any>, import("../config").ITransportPayoad>>;
}
